@@ -26,14 +26,15 @@
 // lib
 #include "abstractbytearraychecksumparameterset.h"
 
+
 class NoByteArrayChecksumParameterSet : public AbstractByteArrayChecksumParameterSet
 {
-public:
+  public:
     NoByteArrayChecksumParameterSet();
-    ~NoByteArrayChecksumParameterSet() override;
+    virtual ~NoByteArrayChecksumParameterSet();
 
-public: // AbstractByteArrayChecksumParameterSet API
-    const char* id() const override;
+  public: // AbstractByteArrayChecksumParameterSet API
+    virtual const char* id() const;
 };
 
 #endif
